import * as svelte_store from 'svelte/store';

interface Labelable {
    label?: string;
}

interface Pressable {
    pressed: boolean;
}

interface Button extends Pressable, Labelable {
}
declare function createButton(init?: Partial<Button>): {
    state: {
        subscribe: (this: void, run: svelte_store.Subscriber<Button>, invalidate?: ((value?: Button | undefined) => void) | undefined) => svelte_store.Unsubscriber;
        press: () => void;
        release: () => void;
        toggle: () => void;
    };
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
};

interface Controllable {
    controls?: string;
}

interface Expandable {
    expanded: boolean;
}

interface ListItem {
    id: string;
    value: string;
}
interface List {
    items: ListItem[];
    active: number;
    value: string;
}

interface Listbox extends Labelable, Expandable, Controllable, List {
    button?: string;
    menu?: string;
    selected: number;
}
declare function createListbox(init?: Partial<Listbox>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        active: number;
        expanded: boolean;
        selected: number;
        value: string | undefined;
    }>, invalidate?: ((value?: {
        active: number;
        expanded: boolean;
        selected: number;
        value: string | undefined;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    items: (node: HTMLElement) => {
        destroy: () => void;
    };
    item: (node: HTMLElement, value?: string) => {
        update(value?: string): void;
        destroy: () => void;
    };
};

interface Menu extends Labelable, Expandable, Controllable, List {
    button?: string;
    menu?: string;
}
declare function createMenu(init?: Partial<Menu>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        active: number;
        expanded: boolean;
        value: string | undefined;
    }>, invalidate?: ((value?: {
        active: number;
        expanded: boolean;
        value: string | undefined;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    items: (node: HTMLElement) => {
        destroy: () => void;
    };
    item: (node: HTMLElement, value?: string) => {
        update(value?: string): void;
        destroy: () => void;
    };
};

interface Checkable {
    checked: boolean;
}

interface Switch extends Labelable, Checkable {
}
declare function createSwitch(init?: Partial<Switch>): {
    state: {
        subscribe: (this: void, run: svelte_store.Subscriber<Switch>, invalidate?: ((value?: Switch | undefined) => void) | undefined) => svelte_store.Unsubscriber;
        on: () => void;
        off: () => void;
        toggle: () => void;
    };
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
};

export { Button, Listbox, Menu, Switch, createButton, createListbox, createMenu, createSwitch };
